<?php
/*
Plugin Name: Dhiti-Dive
Plugin URI: http://dhiti.com/
Description: Give your readers the power of discovery
Version: 0.922
Author: Dhiti
Author URI: http://dhiti.com
License: GPL
*/

// Make sure we don't expose any info if called directly
if ( !function_exists( 'add_action' ) ) {
        header('HTTP/1.1 403 Forbidden');
        exit;
}

define('DHITIDIVE_HOST', 'dive.dhiti.com');
define('DHITIDIVE_VERSION', '0.922');

define('DHITIDIVE_SESSION_NAME', 'dhitidive_session_name');
define('DHITIDIVE_KEYHOLE_WIDGET', 'dhitidive_keyhole_widget');
define('DHITIDIVE_INTEXT_SEARCH', 'dhitidive_intext_search');
define('DHITIDIVE_SEARCH_BOX', 'dhitidive_search_box');
define('DHITIDIVE_SINGLE_ROW', 'dhitidive_single_row');

define('DHITIDIVE_HIDE_POWEREDBY', 'dhitidive_hide_poweredby');
define('DHITIDIVE_FIRST_USE', 'dhitidive_first_use');
define('DHITIDIVE_MANUAL_PLACEMENT', 'dhitidive_manual_placement');
define('DHITIDIVE_CSRF', 'dhitidive_csrf');
define('DHITIDIVE_ENABLE_TOPIC_PAGES', 'dhitidive_enable_topics');
define('DHITIDIVE_RENDER_TOPICS_WITH_AJAX', 'dhitidive_ajax_rendering');
define('DHITIDIVE_TOPIC_PREFIX', 'dhitidive_topic_prefix');
define('DHITIDIVE_SESSION_PREFIX', 'dhitidive_session_prefix');
define('DHITIDIVE_USER_TOPIC_TEMPLATE', 'dhitidive_user_topic_template');
define('DHITIDIVE_BOT_TOPIC_TEMPLATE', 'dhitidive_bot_topic_template');


$dhiti_directory = WP_PLUGIN_DIR.'/'.basename(dirname(__FILE__)).'/';

global $dhiti_admin_url, $dhiti_widget_shown, $dhiti_admin_param, $dhiti_session_name;
$dhiti_admin_url = WP_PLUGIN_URL.'/'.basename(dirname(__FILE__)).'/';

$dhiti_widget_shown = false;
$dhiti_session_name = get_option(DHITIDIVE_SESSION_NAME);


if (function_exists("admin_url"))
	$dhiti_admin_param = basename(__FILE__);
else
  $dhiti_admin_param = basename(dirname(__FILE__))."/".basename(__FILE__);

class DhitiDive {
	
	static function install() {
		add_option(DHITIDIVE_SESSION_NAME, '', '', 'yes');
		add_option(DHITIDIVE_KEYHOLE_WIDGET, 'yes', '', 'yes');
		add_option(DHITIDIVE_INTEXT_SEARCH, 'yes', '', 'yes');
		add_option(DHITIDIVE_SEARCH_BOX, 'yes', '', 'yes');
		add_option(DHITIDIVE_SINGLE_ROW, 'no', '', 'yes');

		add_option(DHITIDIVE_HIDE_POWEREDBY, '', '', 'yes');
		add_option(DHITIDIVE_FIRST_USE, 'yes', '', 'yes');
		add_option(DHITIDIVE_MANUAL_PLACEMENT, 'no', '', 'yes');
		add_option(DHITIDIVE_ENABLE_TOPIC_PAGES, 'yes', '', 'yes');
		add_option(DHITIDIVE_RENDER_TOPICS_WITH_AJAX, 'yes', '', 'yes');

		$homeUrl = get_option("home");
		if (!$homeUrl) $homeUrl = get_option("siteurl");
		$blogdir = parse_url($homeUrl, PHP_URL_PATH);
    $blogdir = rtrim($blogdir, "/");

		add_option(DHITIDIVE_TOPIC_PREFIX, $blogdir . '/hubs/', '', 'yes');
		add_option(DHITIDIVE_USER_TOPIC_TEMPLATE, 'default', '', 'yes');
		add_option(DHITIDIVE_BOT_TOPIC_TEMPLATE, 'default', '', 'yes');
	}
	
	static function uninstall() {
		delete_option(DHITIDIVE_SESSION_NAME);
		delete_option(DHITIDIVE_KEYHOLE_WIDGET);
		delete_option(DHITIDIVE_INTEXT_SEARCH);
		delete_option(DHITIDIVE_SEARCH_BOX);
		delete_option(DHITIDIVE_SINGLE_ROW);

		delete_option(DHITIDIVE_HIDE_POWEREDBY);
		delete_option(DHITIDIVE_FIRST_USE);
		delete_option(DHITIDIVE_MANUAL_PLACEMENT);
		delete_option(DHITIDIVE_CSRF);
		delete_option(DHITIDIVE_ENABLE_TOPIC_PAGES);
		delete_option(DHITIDIVE_RENDER_TOPICS_WITH_AJAX);
		delete_option(DHITIDIVE_TOPIC_PREFIX);
		delete_option(DHITIDIVE_USER_TOPIC_TEMPLATE);
		delete_option(DHITIDIVE_BOT_TOPIC_TEMPLATE);
	}
	
	static function addAdminMenu() {
		global $dhiti_admin_url, $dhiti_admin_param;
		add_menu_page('Dhiti Dive Options', '&nbsp;Dhiti Dive', 'manage_options', $dhiti_admin_param, array('DhitiDive', 'getOptionsPage'), $dhiti_admin_url.'dhiti-small.gif');
	}
	
	function site_url($path = '', $scheme = null) {
		if (function_exists('site_url'))
			return site_url($path, $scheme); 
			
		$url = get_option('siteurl');
		if ( !empty($path) && is_string($path) && strpos($path, '..') === false )
		$url .= '/' . ltrim($path, '/');

		return $url;
	}
	
	static function admin_url($path = '') {
		if (function_exists('admin_url'))
			return admin_url($path); 
			
		$url = DhitiDive::site_url('wp-admin/', 'admin');
		if ( !empty($path) && is_string($path) && strpos($path, '..') === false )
		$url .= ltrim($path, '/');

		return $url;
	}
	
	static function current_url() {
    $protocol = 'http';
    if ($_SERVER['SERVER_PORT'] == 443 || (!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on')) {
        $protocol .= 's';
        $protocol_port = $_SERVER['SERVER_PORT'];
    } else {
        $protocol_port = 80;
    }
    $host = $_SERVER['HTTP_HOST'];
    $port = $_SERVER['SERVER_PORT'];
    $request = $_SERVER['REQUEST_URI'];
    $query = substr($_SERVER['argv'][0], strpos($_SERVER['argv'][0], '?') + 1);
    return  $protocol . '://' . $host . ($port == $protocol_port ? '' : ':' . $port) . $request . (empty($query) ? '' : '?' . $query);
	}
	
	static function adminHead() {
		if (get_option(DHITIDIVE_FIRST_USE) == 'yes') {
			global $dhiti_admin_param;
	    $optionsUrl = DhitiDive::admin_url("admin.php") . "?page=".$dhiti_admin_param;
			?><script>window.location = '<?php echo $optionsUrl?>';</script>
			<?php 
				update_option(DHITIDIVE_FIRST_USE, 'ok');
				die;
		}		
	}
	
	static function addCustomHeader() {
		global $wp_query, $dhiti_session_name;
		if (!$dhiti_session_name || ($wp_query->dhiti_explore !== 1 && (is_feed() || is_preview() || !is_single() || is_attachment()))) return;
		if ($wp_query->dhiti_explore === 1) {
			?><link type="text/css" rel="stylesheet" href="http://<?php echo DHITIDIVE_HOST?>/css/topics.css" media="screen">
<script>var DhitiHost = "<?php echo DHITIDIVE_HOST?>";</script>			
<script type="text/javascript" src="http://<?php echo DHITIDIVE_HOST?>/scripts/topics.js"></script><?php 
		} else {
			?><link type="text/css" rel="stylesheet" href="http://<?php echo DHITIDIVE_HOST?>/css/widget.css" media="screen" id="widgetcss"><?php
		} 
	}
	
	static function get_option($name, $default) {
		$value = get_option($name, $default);
		if (!$value) return $default;
		return $value;
	}
	
	static function getFooterWidgetScript() {
		global $dhiti_session_name;
		
		$id = "dhiti-dive-".rand(0, 10000);
		$includeKeyhole = get_option(DHITIDIVE_KEYHOLE_WIDGET);
		$hidePoweredBy = get_option(DHITIDIVE_HIDE_POWEREDBY);
		$enableTopics = get_option(DHITIDIVE_ENABLE_TOPIC_PAGES);
		$enableIntextSearch = DhitiDive::get_option(DHITIDIVE_INTEXT_SEARCH, "no");
		$enableSearchBox = DhitiDive::get_option(DHITIDIVE_SEARCH_BOX, "no");
		$singleRow = DhitiDive::get_option(DHITIDIVE_SINGLE_ROW, "no");

		if ($enableTopics) {
      $homeUrl = get_option("home");
      if (!$homeUrl) $homeUrl = get_option("siteurl");
      $blogdir = parse_url($homeUrl, PHP_URL_PATH);
      $blogdir = rtrim($blogdir, "/");
      $prefix = DhitiDive::get_option(DHITIDIVE_TOPIC_PREFIX, $blogdir . "/hubs/");
    } else {
      $prefix = "";
    }

		ob_start();
		?><div id="<?php echo $id?>" class="dhiti-widget" style="display:none;clear:both;" dhiti="intext-search:<?php echo $enableIntextSearch?>; hpfx:<?php echo $prefix?>; hide-attribution: <?php echo $hidePoweredBy?>; search-box: <?php echo $enableSearchBox?>; single-row: <?php echo $singleRow?>;"></div>
<script type="text/javascript" defer="defer" async="true"><!--
    (function(){var d=document,w=window,r=d.referrer,h=typeof(Dhiti)!="undefined"&&Dhiti.isWidgetShown,id="<?php echo $id?>",u=d.location.protocol+"//<?php echo DHITIDIVE_HOST?>/widget/<?php echo $dhiti_session_name?>/3?t=3&n=4&kh=<?php echo $includeKeyhole?>&rc=false&dq=1&d="+id;u+="&u="+escape('<?php echo get_permalink()?>').replace(/&/g,"%26")+"&rr="+escape(r).replace(/&/g,"%26");if(!h){var e=d.createElement("script");e.type="text/javascript";e.src=u;setTimeout(function(){d.getElementsByTagName("head")[0].appendChild(e);},10);}else{Dhiti.addScript(u);}})();
//-->    
</script><?php
		return ob_get_clean();
	}
	
	static function addWidgetScript($content) {
		global $dhiti_widget_shown, $dhiti_session_name;
		
		if (!$dhiti_session_name || is_feed() || is_preview() || !is_single() || is_attachment() || $dhiti_widget_shown || DhitiDive::get_option(DHITIDIVE_MANUAL_PLACEMENT, "no") == "yes") {
			return $content;
		}
				
		$dhiti_widget_shown = true;
		
		return $content.DhitiDive::getFooterWidgetScript();
	}
	
	static function addTopicPage($content) {
		global $dhiti_widget_shown, $wp_query, $dhiti_session_name;
    $ajaxRendering = get_option(DHITIDIVE_RENDER_TOPICS_WITH_AJAX);

		if (!$dhiti_session_name || $wp_query->dhiti_explore !== 1 || $wp_query->searchEngine || !$ajaxRendering)
			return $content;
						
		$dhiti_widget_shown = true;
		
		ob_start();
?>
<script type="text/javascript">
  (function(){var d=document,w=window,h=typeof(Dhiti)!="undefined"&&Dhiti.isWidgetShown,id="<?php echo $wp_query->dhiti_id?>",u="<?php echo $wp_query->dhiti_url?>&script=1&d="+id;if(!h){var e=d.createElement("script");e.type="text/javascript";e.src=u;setTimeout(function(){d.getElementsByTagName("head")[0].appendChild(e);},10);}else{Dhiti.addScript(u);}})();
</script>
<?php
		$content .= ob_get_clean();
		
		$content = apply_filters('dhiti_post_content', $content);
		
		return $content;
	}
	
	function the_title($title, $id = 0) {
		global $wp_query;
		if (($id == 0 || $id == -1) && $wp_query->dhiti_explore === 1) {
			return $wp_query->post->post_title;
		}
		return $title;
	}
	
	function the_permalink($link) {
		global $wp_query;
		if (stripos($link, "=-1") !== false && $wp_query->dhiti_explore === 1) {
			return DhitiDive::current_url();
		}
		return $link;
	}
	
	function page_template($template) {
		global $wp_query, $dhiti_directory;
		if ($wp_query->dhiti_explore === 1) {
			if ($wp_query->searchEngine) {
				$tmpl = DhitiDive::get_option(DHITIDIVE_BOT_TOPIC_TEMPLATE, "default");
				if ($tmpl != "default") {
					if ($tmpl == 'bot-template.php')
						$template = $dhiti_directory.$tmpl;
					else 
						$template = TEMPLATEPATH."/".$tmpl;
				}
			} else {
				if (DhitiDive::get_option(DHITIDIVE_USER_TOPIC_TEMPLATE, "default") != "default") {
					$template = TEMPLATEPATH."/".get_option(DHITIDIVE_USER_TOPIC_TEMPLATE);
				}
			}
		}
		
		return $template;
	}
		
	function explore() {
		global $dhiti_session_name;
		if (!$dhiti_session_name) {
			return;
		}
		$homeUrl = get_option("home");
		if (!$homeUrl) $homeUrl = get_option("siteurl");
		$blogdir = parse_url($homeUrl, PHP_URL_PATH);
    $blogdir = rtrim($blogdir, "/");

		$enable = get_option(DHITIDIVE_ENABLE_TOPIC_PAGES);
		$prefix = DhitiDive::get_option(DHITIDIVE_TOPIC_PREFIX, $blogdir . "/hubs/");
		$sessionPrefix = DhitiDive::get_option(DHITIDIVE_SESSION_PREFIX, "");
		$ajaxRendering = get_option(DHITIDIVE_RENDER_TOPICS_WITH_AJAX);

		if ($enable && (is_404() || DhitiDive::get_option("permalink_structure", "?p=%post_id%") == "?p=%post_id%")) {
			global $wp_query;
		  $uri = $_SERVER['REQUEST_URI'];
		  
		  $tmp = preg_replace('/\/$/i', '(/(.*))?', $prefix);
		  $tmp = str_replace("/", "\\/", $tmp);
		  $prefixExpr = "/^".$tmp."$/i";
		  
		  $hasSessionPrefix = false;
		  if ($sessionPrefix) {
		  	$idx = stripos($uri, $prefix);
		  	if ($idx === false ) {
		  		$idx = stripos($uri, substr($prefix, 0, -1));
		  	}
		  	if ($idx !== false && $idx > 0) {
		  		$dhiti_session_name = substr($uri, 1, $idx-1);
		  		$uri = substr($uri, $idx);
		  		$hasSessionPrefix = true;
		  	}
		  }
		  
			$uri = urldecode(preg_replace('/\?.*/', '', $uri));
		  $matches = Array();

		  if (preg_match($prefixExpr, $uri, $matches)) {
				status_header(200);
				$wp_query->is_page = $wp_query->dhiti_explore = 1; 
				$wp_query->is_home = $wp_query->is_404 = $wp_query->is_single = $wp_query->is_post = $wp_query->is_feed = $wp_query->is_trackback = 0;

				$wp_query->dhiti_id = "dhiti-dive-".rand(0, 10000);
				
				$match = "";
				if (count($matches) > 2 && $matches[2])
					$match = $matches[2];
				$parts = explode("/", $match);
				$title = Array();
				$topics = Array();
				$categories = Array();
				for ($i=0;$i<count($parts);$i++) {
					$matches = array();
					if (preg_match('/^(.*)_([0-9]+$)/', $parts[$i], $matches)) {
						$categories[] = str_ireplace("_", " ", $matches[2]);
						$title[] = str_ireplace("_", " ", $matches[1]);
					} else {
						$text = str_ireplace("_", " ", $parts[$i]);
						$title[] = $text;
						$topics[] = $text;
					}
				}
				
				$wp_query->dhiti_categories = implode(",", $categories);
				$wp_query->dhiti_topics = implode(" ", $topics);
				
				$post = new StdClass;
				$post->ID = -1;
				$post->post_author = -1;
				$post->date = time();
				$post->post_modified = time();
				$post->post_title = implode(" ", $title);
				$post->post_category = 0;
				$post->post_excerpt = "";
				$post->post_status = "publish";
				$post->comment_status = closed;
				$post->comment_count = 0;
				$post->guid = DhitiDive::current_url();
				$post->ping_status = "closed"; 
				$post->post_password = ""; 
				$post->post_name = title; 
				$post->post_type = "page"; 
				$post->post_parent = 0;
				
				$topic_landing_page = false;
				if (!trim($post->post_title)) { 
					$post->post_title = "Explore";
					$topic_landing_page = true;
				}
				
				$wp_query->searchEngine = false;
				if (stripos($_SERVER['REQUEST_URI'], "search=yes") > 0 or preg_match("/Googlebot|Yahoo|Slurp|msnbot|Openbot|AltaVista|Gigabot|Lycos|Yammybot|ia_archiver|Scooter|Teoma/i", $_SERVER['HTTP_USER_AGENT']) == 1)
					$wp_query->searchEngine = true;

				$topics = urlencode($wp_query->dhiti_topics);
				$categories = $wp_query->dhiti_categories;
        $homeUrl = get_option("home");
        if (!$homeUrl) $homeUrl = get_option("siteurl");
        $blogdir = parse_url($homeUrl, PHP_URL_PATH);
        $blogdir = rtrim($blogdir, "/");
				
				$prefix = DhitiDive::get_option(DHITIDIVE_TOPIC_PREFIX, $blogdir . "/hubs/");
				if ($hasSessionPrefix) $prefix = "/".$dhiti_session_name.$prefix;
				$url = "http://".DHITIDIVE_HOST."/explore/?session=".$dhiti_session_name."&c=".$categories."&l=".$topics."&u=".DhitiDive::current_url()."&p=".$prefix."&ip=".$_SERVER["REMOTE_ADDR"]."&rr=".urlencode($_SERVER["HTTP_REFERER"]);
				$html = "";
				if ($wp_query->searchEngine || !$ajaxRendering) { // static topic page for bots, or if ajax rendering is disabled.
					$oldErrorLevel = error_reporting();
					error_reporting(0);
					ob_start();
					global $dhiti_widget_shown;
					$html = file_get_contents($url."&agent=".urlencode($_SERVER['HTTP_USER_AGENT']));
					ob_end_clean();
					error_reporting($oldErrorLevel);
					$html = preg_replace('/[\r\n]+/', " ", $html);
					$dhiti_widget_shown = true;
				}
				$post->post_content = '<div id="'.$wp_query->dhiti_id.'" class="'.($topic_landing_page?'dhiti-topic-home':'dhiti-topic-page').' dhiti-topics dhiti-widget '.($wp_query->searchEngine?'dhiti-search':'').'" style="clear:both;">'.$html.'</div>';
				
				$wp_query->post = $post;
				$wp_query->dhiti_url = $url;
								
				$wp_query->queried_object = &$post;
				$wp_query->queried_object_id = (int) $post->ID;
				
				$wp_query->posts = Array($wp_query->post);
				$wp_query->post_count = 1;
				
				add_filter('the_title', array('DhitiDive', 'the_title'), 10, 2);
				add_filter('the_permalink', array('DhitiDive', 'the_permalink'));
				add_filter('the_content', array('DhitiDive', 'addTopicPage'));
				add_filter('page_template', array('DhitiDive', 'page_template'));
				
				$post->post_content =  apply_filters('dhiti_pre_content', "").$post->post_content;
				
			}
		}
	}

	static function getOptionsPage() {
		//must check that the user has the required capability
		if (!current_user_can('manage_options')) {
			wp_die(__('You do not have sufficient permissions to access this page.'));
		}

    
		$submitField = 'dive-submit';
		
		$session_name = get_option(DHITIDIVE_SESSION_NAME);
		$keyhole = get_option(DHITIDIVE_KEYHOLE_WIDGET);
		$enableIntextSearch = get_option(DHITIDIVE_INTEXT_SEARCH);
		$enableSearchBox = get_option(DHITIDIVE_SEARCH_BOX);
		$singleRow = get_option(DHITIDIVE_SINGLE_ROW);
		
		$hidePowered = get_option(DHITIDIVE_HIDE_POWEREDBY);
		$manualPlacement = DhitiDive::get_option(DHITIDIVE_MANUAL_PLACEMENT, "no");
		$firstUse = DhitiDive::get_option(DHITIDIVE_FIRST_USE, "");
		$userTopicTemplate = DhitiDive::get_option(DHITIDIVE_USER_TOPIC_TEMPLATE, "default");
		$botTopicTemplate = DhitiDive::get_option(DHITIDIVE_BOT_TOPIC_TEMPLATE, "default");
		$enableTopics = get_option(DHITIDIVE_ENABLE_TOPIC_PAGES);
		$ajaxRendering = get_option(DHITIDIVE_RENDER_TOPICS_WITH_AJAX);

		$homeUrl = get_option("home");
		if (!$homeUrl) $homeUrl = get_option("siteurl");
		$blogdir = parse_url($homeUrl, PHP_URL_PATH);
    $blogdir = rtrim($blogdir, "/");

		$topicPrefix = DhitiDive::get_option(DHITIDIVE_TOPIC_PREFIX, $blogdir . "/hubs/");

		$category_base = DhitiDive::get_option('category_base', 'category');
		$tag_base = DhitiDive::get_option( 'tag_base', 'tag');
		
		if (!$category_base) $category_base = "category";
		if (!$tag_base) $tag_base = "tag";
		
		$category_base = "/".trim($category_base, " /")."/";
		$tag_base = "/".trim($tag_base, " /")."/";
		
		$homeUrl = get_option("home");
		if (!$homeUrl) $homeUrl = get_option("siteurl");
		
		if ($firstUse == "ok")
			delete_option(DHITIDIVE_FIRST_USE);
		
		global $dhiti_admin_param;
	  $thisPageUrl = DhitiDive::admin_url("admin.php") . "?page=".$dhiti_admin_param;
	  
	  $locale = "en_US";
	  
	  if (function_exists("get_locale")) {
	  	$locale = get_locale();
	  }
	  
		// See if the user has posted us some information
		// If they did, this hidden field will be set to 'Y'
		if( isset($_POST[$submitField]) && $_POST[$submitField] == 'Y') {
			$csrf = $_POST['csrf'];
			$validCSRF = false;
			if (!empty($csrf)) {
				if (function_exists('wp_verify_nonce')) {
					$validCSRF = wp_verify_nonce($csrf, "dhiti-dive");
				} else {
					$validCSRF = $csrf == DhitiDive::get_option(DHITIDIVE_CSRF, "");
			    delete_option(DHITIDIVE_CSRF);
				}
			}
  		if ($validCSRF) {
				$session_name = $_POST[DHITIDIVE_SESSION_NAME];
				
				update_option(DHITIDIVE_SESSION_NAME, $session_name);
				
				if ($_POST['detailed_settings']) {
					$keyhole = $_POST[DHITIDIVE_KEYHOLE_WIDGET];
					update_option(DHITIDIVE_KEYHOLE_WIDGET, $keyhole);

					$enableIntextSearch = $_POST[DHITIDIVE_INTEXT_SEARCH];
					update_option(DHITIDIVE_INTEXT_SEARCH, $enableIntextSearch);

					$enableSearchBox = $_POST[DHITIDIVE_SEARCH_BOX];
					update_option(DHITIDIVE_SEARCH_BOX, $enableSearchBox);

					$singleRow = $_POST[DHITIDIVE_SINGLE_ROW];
					update_option(DHITIDIVE_SINGLE_ROW, $singleRow);
					
					$hidePowered = $_POST[DHITIDIVE_HIDE_POWEREDBY];
					update_option(DHITIDIVE_HIDE_POWEREDBY, $hidePowered);
					
					$manualPlacement = $_POST[DHITIDIVE_MANUAL_PLACEMENT];
					update_option(DHITIDIVE_MANUAL_PLACEMENT, $manualPlacement);
					
					$userTopicTemplate = $_POST[DHITIDIVE_USER_TOPIC_TEMPLATE];
					update_option(DHITIDIVE_USER_TOPIC_TEMPLATE, $userTopicTemplate);
					
					$botTopicTemplate = $_POST[DHITIDIVE_BOT_TOPIC_TEMPLATE];
					update_option(DHITIDIVE_BOT_TOPIC_TEMPLATE, $botTopicTemplate);

					$enableTopics = $_POST[DHITIDIVE_ENABLE_TOPIC_PAGES];
					update_option(DHITIDIVE_ENABLE_TOPIC_PAGES, $enableTopics);

					$ajaxRendering = $_POST[DHITIDIVE_RENDER_TOPICS_WITH_AJAX];
					update_option(DHITIDIVE_RENDER_TOPICS_WITH_AJAX, $ajaxRendering);
					
					$topicPrefix = trim($_POST[DHITIDIVE_TOPIC_PREFIX]);
					if (!$topicPrefix) {
					  $topicPrefix = $blogdir . "/hubs/";
					}
          if (substr($topicPrefix, 0, 1) != "/") $topicPrefix = "/".$topicPrefix;
          if (substr($topicPrefix, strlen($topicPrefix)-1, 1) != "/") $topicPrefix = $topicPrefix."/";
					update_option(DHITIDIVE_TOPIC_PREFIX, $topicPrefix);
				}
				
	?>

	<div class="updated">
	<p><strong><?php _e('settings saved.', 'menu-test' ); ?></strong></p>
	</div>
	<?php
			} else {
	?>
	<div class="error">
	<p><strong><?php _e('Invalid Request.', 'menu-test' ); ?></strong></p>
	</div>
	<?php
			}
		}
		if (function_exists('wp_create_nonce'))
			 $csrf = wp_create_nonce("dhiti-dive");
		else {
			delete_option(DHITIDIVE_CSRF);
			$csrf = rand(0, 100000)."9".rand(0, 100000);
			add_option(DHITIDIVE_CSRF, $csrf);
		}
		
		if ($firstUse == "ok") {?>
	<div class="updated">
		<p><strong>Thank you for installing Dhiti Dive.  If you already have a 'Dhiti ID' just enter it here. You can also request for one to complete the installation.</strong></p>
	  <img src="http://<?php echo DHITIDIVE_HOST?>/nuggetize/log/activate/1/wordpress/<?php echo $locale?>" width="1" height="1" border="0"/>
	</div>
<?php }
		
		if (stripos($locale, "en") != 0) {?>

	<div class="error">
		<p><strong>Dhiti Dive supports only English Language Blogs.</strong></p>
	</div>
<?php
		}
?>
	<div class="wrap">
	<h2>Dhiti Dive Settings</h2>
	<form name="form1" method="post" action="">
	  <input type="hidden" name="csrf" value="<?php echo $csrf?>"/>
	  <input type="hidden" name="<?php echo $submitField; ?>" value="Y"/>
	<table class="form-table">
	  <tr><td><label for="sessionName">Dhiti ID:</td><td>
	    <input type="text" id="sessionName" name="<?php echo DHITIDIVE_SESSION_NAME; ?>" value="<?php echo $session_name; ?>" size="20">
	    <?php if (!$session_name) {?>
	    <span class="description">If you already have your Dhiti Id.</span>
	    <?php } else {?>
	    <span class="description">Explore your blog at <a href="http://<?php echo DHITIDIVE_HOST?>/<?php echo $session_name?>">http://<?php echo DHITIDIVE_HOST?>/<?php echo $session_name?></a></span>
	    <?php } ?>
	  </td></tr>
    <?php if ($session_name) {?>

    <tr><td><b>Basic options:</b></td></tr>

    <input type="hidden" id="detailed_settings" name="detailed_settings" value="yes">
	  <tr><td><label for="topic_pages" >Enable hub pages on your site:</label></td><td>
	    <input type="checkbox" id="topic_pages" name="<?php echo DHITIDIVE_ENABLE_TOPIC_PAGES; ?>" value="yes" <?php echo $enableTopics=='yes'?'checked':''; ?>>
	    &nbsp;&nbsp; <span class="description">(Create focused hubpages on your site)</span>
	  </td></tr>

	  <tr><td width="200px"><label for="keyhole" >Enrich well-covered topics with a hover widget:</label></td><td>
	    <input type="checkbox" id="keyhole" name="<?php echo DHITIDIVE_KEYHOLE_WIDGET; ?>" value="yes" <?php echo $keyhole=='yes'?'checked':''; ?>> &nbsp;&nbsp; <span class="description">(We can automatically identify topics on which you have a lot of coverage, and decorate some occurrences with our hover widget - ensuring an enriched experience for your readers).
	  </td></tr>

	  <tr><td width="200px"><label for="intext_search" >Enable discovery on text selection:</label></td><td>
	    <input type="checkbox" id="intext_search" name="<?php echo DHITIDIVE_INTEXT_SEARCH; ?>" value="yes" <?php echo $enableIntextSearch=='yes'?'checked':''; ?>> &nbsp;&nbsp; <span class="description">(Users can lookup relevant information from the rest of your site for any piece of text they select). 
	  </td></tr>

    <tr><td><b>Advanced options:</b></td></tr>

    <tr><td><b>Article recommendations</b></td></tr>

	  <tr><td width="200px"><label for="search_box" >Show search box:</label></td><td>
	    <input type="checkbox" id="search_box" name="<?php echo DHITIDIVE_SEARCH_BOX; ?>" value="yes" <?php echo $enableSearchBox=='yes'?'checked':''; ?>> &nbsp;&nbsp; <span class="description">(Show our exploratory search box in the footer widget). 
	  </td></tr>

	  <tr><td width="200px"><label for="single_row" >Show article recommendations in a single row:</label></td><td>
	    <input type="checkbox" id="single_row" name="<?php echo DHITIDIVE_SINGLE_ROW; ?>" value="yes" <?php echo $singleRow=='yes'?'checked':''; ?>> &nbsp;&nbsp; <span class="description">(Show only one row of article recommendations). 
	  </td></tr>

	  <tr><td style="vertical-align:top"><label for="manual" >Add the content recommendation widget manually:</label></td><td>
	    <input type="checkbox" id="manual" onclick="document.getElementById('manualDetails').style.display=this.checked?'block':'none';" name="<?php echo DHITIDIVE_MANUAL_PLACEMENT; ?>" value="yes" <?php echo $manualPlacement=='yes'?'checked':''; ?>>
	    &nbsp;&nbsp; <span class="description">(We place our content recommendation widget right after the article. You can use our script if you want control over its placement. If you are using this option, please ensure you re-copy and insert the script everytime you change options.)</span>
	    <div id="manualDetails" style="display:<?php echo $manualPlacement=='yes'?'block':'none'; ?>;">
	      <br/><span class="description">Insert the following script into your page template manually</span><br/>
	      <textarea style="font-size:7pt;" rows=3 cols=100 readonly><?php echo DhitiDive::getFooterWidgetScript()?></textarea>
	    </div>
	  </td></tr>

	  <tr style="display:none;"><td><label for="keyhole" >Hide 'Powered by Dhiti':</label></td><td>
	    <input type="checkbox" id="keyhole" name="<?php echo DHITIDIVE_HIDE_POWEREDBY; ?>" value="yes" <?php echo $hidePowered=='yes'?'checked':''; ?>>
	    &nbsp;&nbsp; <span class="description">(Please consider retaining our logo and link)</span>
	  </td></tr>

    <tr><td><b>Hubs</b></td></tr>

		<tr><td><label for="topicPrefix">Create hub pages under: </label></td><td>
			<input name="<?php echo DHITIDIVE_TOPIC_PREFIX; ?>" id="topicPrefix" value="<?php echo $topicPrefix?>" />
	  </td></tr>

	  <tr><td><label for="ajax_rendering" >Render hub pages using Ajax for users:</label></td><td>
	    <input type="checkbox" id="ajax_rendering" name="<?php echo DHITIDIVE_RENDER_TOPICS_WITH_AJAX; ?>" value="yes" <?php echo $ajaxRendering=='yes'?'checked':''; ?>>
	    &nbsp;&nbsp; <span class="description">(Lesser load on your server. Lower latency. Search engines will get static pages so they can index correctly. Disabling this option will send same static html to both search engines and your users.)</span>
	  </td></tr>

		<tr><td><label for="userTopicTemplate">Hub page Template for end-users:</label></td><td>
			<select name="<?php echo DHITIDIVE_USER_TOPIC_TEMPLATE; ?>" id="userTopicTemplate">
			<option value='default'>Default Template</option>
			<?php page_template_dropdown($userTopicTemplate); ?>
			</select>
	  </td></tr>
		<tr><td><label for="botTopicTemplate">Hub page Template for Search Engines:</label></td><td>
			<select name="<?php echo DHITIDIVE_BOT_TOPIC_TEMPLATE; ?>" id="botTopicTemplate">
			<option value='default'>Default Template</option>
			<option value='bot-template.php' <?php echo $botTopicTemplate == 'bot-template.php'?'selected':''?>>Dhiti template for search engine</option>
			<?php page_template_dropdown($botTopicTemplate); ?>
			</select>
	    &nbsp;&nbsp; <span class="description">(This template will be used only for visits from search engines.  Please avoid placing any other widget in this template.)</span>
	  </td></tr>

	  <?php } ?>
	  <tr><td colspan=2> 
	    
	  </td></tr>
	</table> 
		
	<p class="submit"><input type="submit" name="Submit"
		class="button-primary" value="Save!" /></p>
	</form>

	<?php if (!$session_name) { ?>
	<h2>Request Dhiti Dive for your site</h2>
	<form name="form2" method="post" action="http://<?php echo DHITIDIVE_HOST?>/wordpress_request">
	  <input type="hidden" name="title" value="<?php echo get_option('blogname')?>"/>
	  <input type="hidden" name="url" value="<?php echo $homeUrl?>"/>
	  <input type="hidden" name="permalink_structure" value="<?php echo get_option('permalink_structure')?>"/>
	  <input type="hidden" name="return" value="<?php echo $thisPageUrl?>"/>
	  <input type="hidden" name="email" value="<?php echo get_option('admin_email') ?>"/>
	  <input type="hidden" name="csrf" value="<?php echo $csrf?>"/>
	  <input type="hidden" name="exclude" value="<?php echo $category_base?>|<?php echo $tag_base?>|/author/|/page/"/>
		<p>Following information will be sent to our server.  This information will help us identify your article pages from your other pages. It will initiate crawling of your blog and return <b>Dhiti ID</b> for the widget.</p>
		<table class="form-table">
		  <tr><td>Title</td><td><?php echo get_option('blogname')?></td></tr>
		  <tr><td>Blog URL</td><td><?php echo $homeUrl?></td></tr>
		  <tr><td>Email</td><td><?php echo get_option('admin_email')?></td></tr>
		  <tr><td>Permalink Structure</td><td><?php echo DhitiDive::get_option('permalink_structure', '/?p=%post_id%')?></td></tr>
		  <tr><td>Exclude Pages</td><td><?php echo $category_base ?>*, <?php echo $tag_base ?>*, /author/*, /page/*</td></tr>
		  <tr><td>Return Url</td><td><?php echo $thisPageUrl?></td></tr>
		  <tr><td>Auth Token</td><td><?php echo $csrf?> <span class="description">(Helps us indentify your site)</span></td></tr>
		</table>
	<p class="submit"><input type="submit" name="Submit"
		class="button-primary" value="Send Request" /></p>
	</form>
	<hr/>
	<?php } ?>
	</div>
	<?php

	}
}	
        
if (is_admin()) {
	register_activation_hook($dhiti_directory . '/dhiti-dive.php', array('DhitiDive', 'install'));
	register_deactivation_hook($dhiti_directory . '/dhiti-dive.php', array('DhitiDive', 'uninstall'));
	add_action('admin_menu', array('DhitiDive', 'addAdminMenu'));
	add_action('admin_head', array('DhitiDive', 'adminHead'));
}

add_filter('the_content', array('DhitiDive', 'addWidgetScript'));
add_filter('wp_head', array('DhitiDive', 'addCustomHeader'));

add_filter('template_redirect', array('DhitiDive', 'explore'), 1);

?>
